package net.wanji.opt.service.strategy.impl;

import cn.hutool.core.util.ObjectUtil;
import net.wanji.opt.dao.mapper.strategy.IdeaMapper;
import net.wanji.opt.dto.IntegerIdsDTO;
import net.wanji.opt.dto.strategy.AddOrUpdateIdeaDTO;
import net.wanji.opt.dto.strategy.QueryIdeaDTO;
import net.wanji.opt.po.strategy.IdeaPO;
import net.wanji.opt.service.strategy.IdeaService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * @author Kent HAN
 * @date 2023/2/27 9:43
 */
@Service
public class IdeaServiceImpl implements IdeaService {
    private final IdeaMapper ideaMapper;

    public IdeaServiceImpl(IdeaMapper ideaMapper) {
        this.ideaMapper = ideaMapper;
    }

    @Override
    @Transactional
    public void addOrUpdateIdea(AddOrUpdateIdeaDTO addOrUpdateIdeaDTO) {
        Integer id = addOrUpdateIdeaDTO.getId();
        if (id == 0 || ObjectUtil.isEmpty(id)) {
            // 不传ID为新增
            IdeaPO ideaPO = new IdeaPO();
            ideaPO.setIdeaCode(addOrUpdateIdeaDTO.getIdeaCode());
            ideaPO.setIdeaName(addOrUpdateIdeaDTO.getIdeaName());
            ideaPO.setIdeaTarget(addOrUpdateIdeaDTO.getIdeaTarget());
            ideaPO.setIdeaDetail(addOrUpdateIdeaDTO.getIdeaDetail());
            ideaMapper.insertOne(ideaPO);
        } else {
            // 传ID为修改
            IdeaPO ideaPO = new IdeaPO();
            ideaPO.setId(id);
            ideaPO.setIdeaCode(addOrUpdateIdeaDTO.getIdeaCode());
            ideaPO.setIdeaName(addOrUpdateIdeaDTO.getIdeaName());
            ideaPO.setIdeaTarget(addOrUpdateIdeaDTO.getIdeaTarget());
            ideaPO.setIdeaDetail(addOrUpdateIdeaDTO.getIdeaDetail());
            ideaMapper.updateOne(ideaPO);
        }
    }

    @Override
    public void deleteIdea(IntegerIdsDTO integerIdsDTO) {
        List<Integer> ids = integerIdsDTO.getIds();
        ideaMapper.deleteByIds(ids);
        // todo 删除关系表数据
    }

    @Override
    public List<IdeaPO> queryIdea(QueryIdeaDTO queryIdeaDTO) {
        String ideaName = queryIdeaDTO.getIdeaName();
        List<IdeaPO> ideaPOList = ideaMapper.selectByIdeaName(ideaName);
        return ideaPOList;
    }
}
