package net.wanji.opt.service.strategy.impl;

import cn.hutool.core.util.ObjectUtil;
import net.wanji.opt.dao.mapper.strategy.StrategyMapper;
import net.wanji.opt.dto.IntegerIdsDTO;
import net.wanji.opt.dto.strategy.AddOrUpdateStrategyDTO;
import net.wanji.opt.dto.strategy.QueryStrategyDTO;
import net.wanji.opt.po.strategy.StrategyPO;
import net.wanji.opt.service.strategy.StrategyService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * @author Kent HAN
 * @date 2023/2/27 9:43
 */
@Service
public class StrategyServiceImpl implements StrategyService {
    private final StrategyMapper strategyMapper;

    public StrategyServiceImpl(StrategyMapper strategyMapper) {
        this.strategyMapper = strategyMapper;
    }

    @Override
    @Transactional
    public void addOrUpdateStrategy(AddOrUpdateStrategyDTO addOrUpdateStrategyDTO) {
        Integer id = addOrUpdateStrategyDTO.getId();
        if (id == 0 || ObjectUtil.isEmpty(id)) {
            // 不传ID为新增
            StrategyPO strategyPO = new StrategyPO();
            strategyPO.setStrategyCode(addOrUpdateStrategyDTO.getStrategyCode());
            strategyPO.setStrategyName(addOrUpdateStrategyDTO.getStrategyName());
            strategyPO.setStrategyTarget(addOrUpdateStrategyDTO.getStrategyTarget());
            strategyPO.setStrategyDetail(addOrUpdateStrategyDTO.getStrategyDetail());
            strategyMapper.insertOne(strategyPO);
        } else {
            // 传ID为修改
            StrategyPO strategyPO = new StrategyPO();
            strategyPO.setId(id);
            strategyPO.setStrategyCode(addOrUpdateStrategyDTO.getStrategyCode());
            strategyPO.setStrategyName(addOrUpdateStrategyDTO.getStrategyName());
            strategyPO.setStrategyTarget(addOrUpdateStrategyDTO.getStrategyTarget());
            strategyPO.setStrategyDetail(addOrUpdateStrategyDTO.getStrategyDetail());
            strategyMapper.updateOne(strategyPO);
        }
    }

    @Override
    public void deleteStrategy(IntegerIdsDTO integerIdsDTO) {
        List<Integer> ids = integerIdsDTO.getIds();
        strategyMapper.deleteByIds(ids);
        // todo 删除关系表数据
    }

    @Override
    public List<StrategyPO> queryStrategy(QueryStrategyDTO queryStrategyDTO) {
        String strategyName = queryStrategyDTO.getStrategyName();
        List<StrategyPO> strategyPOList = strategyMapper.selectByStrategyName(strategyName);
        return strategyPOList;
    }
}
